@@ -6,10 +6,10 @@ use Carp;
 use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
-use File::Copy qw/copy/;
-use File::Copy::Recursive qw/dircopy/;
+use File::Copy::Recursive qw/rcopy/;
 use Cwd qw/getcwd/;
 use Shipwright::Backend::FS;
+use File::Path qw/remove_tree make_path/;
 
 our %REQUIRE_OPTIONS = ( import => [qw/source/] );
 
@@ -41,14 +41,14 @@ sub initialize {
     my $path = $self->repository;
     $path =~ s!^file://!!;    # this is always true since we check that before
 
-    Shipwright::Util->run( [ 'rm', '-rf', $path ] );
-    Shipwright::Util->run( [ 'mkdir', '-p', $path ] );
+    Shipwright::Util->run( sub { remove_tree( $path ) } );
+    Shipwright::Util->run( sub { make_path( $path ) } );
 
     my $cwd = getcwd;
     chdir $path;
     Shipwright::Util->run( [ $ENV{'SHIPWRIGHT_GIT'}, '--bare', 'init' ] );
 
-    dircopy( $dir, $self->cloned_dir )
+    rcopy( $dir, $self->cloned_dir )
       or confess "can't copy $dir to " . $path . ": $!";
     $self->commit( comment => 'create project' );
     chdir $cwd;
